##################################################################
# Script parameters												 #
##################################################################

PAUSE_ON_MATCH <- 1
PVALUE_MATCH_THRESHOLD <- 0.01

##################################################################
# Main Script													 #
##################################################################

myDataFrame = read.csv("Cerrejonisuchus_CompleteDataset.csv", check.names = FALSE)

colCompletenessThreshold <- .3
rowCompletenessThreshold <- .4

myFilteredData <- myDataFrame 
myFilteredData <- myFilteredData[,colMeans(is.na(myFilteredData))  <= 1-colCompletenessThreshold] 
myFilteredData <- myFilteredData[rowMeans(is.na(myFilteredData)) <= 1-rowCompletenessThreshold,]

numericData <-  myFilteredData[,4:dim(myFilteredData)[2]]
#cladeNames <- droplevels(myFilteredData$Clade)
cladeNames <- myFilteredData$Clade

#legendColors <- c("red","green3","blue")
legendColors <- c("red","green3","black","blue")

#=====================================================#
#===================== PERMANOVA =====================#   
#=====================================================#

library(vegan)

nbrCols <- dim(myFilteredData)[2] - 4

MyPermanoValue <- c()
MyPermanoNames <- c()

{
for(i in 1:(nbrCols-1)){
for(j in (i+1):nbrCols){
	nbrClusters <- length(unique(cladeNames))
	cl_data <- myFilteredData[,c(4+i,4+j)]

	cl_cladeNames <- cladeNames[complete.cases(cl_data)]
	cl_data <- cl_data[complete.cases(cl_data),]

	set.seed(69420) #So that we get always the same result

	#cl_dist<-vegdist(cl_data, method='bray')
	cl_dist<-dist(cl_data)
	permanova <- adonis2(cl_dist~cl_cladeNames,data=cl_data,permutations=199) 
	pvalue <- permanova[1,"Pr(>F)"]
	
	signSymb <- "   " 
	if(!is.na(pvalue))
	{
		if(pvalue < PVALUE_MATCH_THRESHOLD)
		{
			if(PAUSE_ON_MATCH){
				readline(prompt="Press [enter] to continue")
			}
			
			if(pvalue < 0.1)
				 signSymb <- "  ."
			if(pvalue < 0.05)
				 signSymb <- "  *"
			if(pvalue < 0.01)
				 signSymb <- " **"
			if(pvalue < 0.001)
				 signSymb <- "***"
				
			pairs(cl_data, bg=legendColors[cl_cladeNames], pch=21)
			
			rowName <- paste0(colnames(cl_data)[1],"-",colnames(cl_data)[2])
			print(paste0(signSymb,"P-value for ",rowName," = ",pvalue))
			
			MyPermanoNames <- c(MyPermanoNames, rowName)
			MyPermanoValue <- c(MyPermanoValue, pvalue)
			
		}
	}
	
}}


myPermanovaDataframe <- data.frame(MyPermanoValue)
rownames(myPermanovaDataframe) <- MyPermanoNames
colnames(myPermanovaDataframe) <- c("p-value")

}
